@@ -1,12 +1,14 @@
-/*********************************************************************
- * Copyright (c) 2020 Red Hat, Inc.
- *
+/**
+ * Copyright (c) 2019-2021 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- **********************************************************************/
+ *
+ * Contributors:
+ *   Red Hat, Inc. - initial API and implementation
+ */
 
 import { Command, flags } from '@oclif/command'
 import { cli } from 'cli-ux'
@@ -21,8 +23,9 @@ export default class Get extends Command {
 
   static flags: flags.Input<any> = {
     help: flags.help({ char: 'h' }),
-    telemetry: CHE_TELEMETRY
+    telemetry: CHE_TELEMETRY,
   }
+
   async run() {
     const { flags } = this.parse(Get)
     await ChectlContext.init(flags, this)
@@ -37,5 +40,4 @@ export default class Get extends Command {
       cli.info('There is no active login session')
     }
   }
-
 }
